@@ -114,6 +114,7 @@ class CachedObject:
         self.ismethod = inspect.ismethod(self.obj)
         self.ismodule = inspect.ismodule(self.obj)
         self.filters: List[types.FunctionType] = []
+        self.search_filter: str = ""
 
         # Highlighted attributes
         self.typeof: Text = highlighter(str(type(self.obj)))
@@ -154,6 +155,7 @@ class CachedObject:
         return title
 
     def cache(self):
+        # TODO find some places to speed this up
         if not self.public_attributes:
             for attr in self.plain_public_attributes:
                 self.public_attributes[attr] = CachedObject(
@@ -172,16 +174,19 @@ class CachedObject:
 
         self.filter()
 
-    def set_filters(self, filters: List[types.FunctionType]):
+    def set_filters(self, filters: List[types.FunctionType], search_filter: str = ""):
         self.filters = filters
+        self.search_filter = search_filter
         self.filter()
 
     def filter(self):
         self.filtered_public_attributes = {}
-        if not self.filters:
-            self.filtered_public_attributes = self.public_attributes
-        else:
-            for attr, cached_obj in self.public_attributes.items():
+        for attr, cached_obj in self.public_attributes.items():
+            if self.search_filter not in attr.lower():
+                continue
+            if not self.filters:
+                self.filtered_public_attributes[attr] = cached_obj
+            else:
                 # Only keep objects that match the filter
                 for _filter in self.filters:
                     if _filter(cached_obj):
@@ -189,10 +194,12 @@ class CachedObject:
                         break
 
         self.filtered_private_attributes = {}
-        if not self.filters:
-            self.filtered_private_attributes = self.private_attributes
-        else:
-            for attr, cached_obj in self.private_attributes.items():
+        for attr, cached_obj in self.private_attributes.items():
+            if self.search_filter not in attr.lower():
+                continue
+            if not self.filters:
+                self.filtered_private_attributes[attr] = cached_obj
+            else:
                 # Only keep objects that match the filter
                 for _filter in self.filters:
                     if _filter(cached_obj):
@@ -220,18 +227,18 @@ class CachedObject:
 
                 line = Text(" ") + repr_key + Text(": ") + repr_val
                 line.overflow = "ellipsis"
-                self.filtered_dict[key] = (
-                    line,
-                    CachedObject(val, parent_path=self.dotpath, index=key),
-                )
-            if self.filters:
-                for attr, (line, cached_obj) in self.filtered_dict.copy().items():
+
+                cached_obj = CachedObject(val, parent_path=self.dotpath, index=key)
+
+                if type(key) == str and self.search_filter not in key.lower():
+                    continue
+                if self.filters:
                     for _filter in self.filters:
                         if _filter(cached_obj):
-                            self.filtered_dict[attr] = (line, cached_obj)
+                            self.filtered_dict[key] = (line, cached_obj)
                             break
-                    else:
-                        del self.filtered_dict[attr]
+                else:
+                    self.filtered_dict[key] = (line, cached_obj)
 
         self.filtered_list: List[Tuple[Text, CachedObject]] = []
         if type(self.obj) in (list, tuple, set):
@@ -258,6 +265,12 @@ class CachedObject:
                             break
                 self.filtered_list = new_filtered_list
 
+    def current_visible_attributes(self):
+        if self.filtered_dict:
+            return self.filtered_dict
+        elif self.filtered_list:
+            return self.filtered_list
+
     def get_source(
         self, term_height: int = 0, fullscreen: bool = False
     ) -> Union[Syntax, str]:
